@@ -394,6 +394,7 @@ bool OutputModel::setResolution(int outputIndex, int resIndex)
         auto it = modes.begin();
         while (it != modes.end()) {
             if ((*it)->size() == size && (*it)->refreshRate() > bestRefreshRate) {
+                bestRefreshRate = (*it)->refreshRate();
                 modeIt = it;
             }
             it++;
@@ -417,7 +418,7 @@ bool OutputModel::setResolution(int outputIndex, int resIndex)
     QModelIndex index = createIndex(outputIndex, 0);
     // Calling this directly ignores possible optimization when the
     // refresh rate hasn't changed in fact. But that's ok.
-    Q_EMIT dataChanged(index, index, {ResolutionIndexRole, ResolutionRole, SizeRole, RefreshRateIndexRole});
+    Q_EMIT dataChanged(index, index, {ResolutionIndexRole, ResolutionRole, SizeRole, RefreshRatesRole, RefreshRateIndexRole});
     Q_EMIT sizeChanged();
     return true;
 }
@@ -426,7 +427,7 @@ bool OutputModel::setRefreshRate(int outputIndex, int refIndex)
 {
     const Output &output = m_outputs[outputIndex];
     const auto rates = refreshRates(output.ptr);
-    if (refIndex < 0 || refIndex >= rates.size()) {
+    if (refIndex < 0 || refIndex >= rates.size() || !output.ptr->isEnabled()) {
         return false;
     }
     const float refreshRate = rates[refIndex];
