@@ -34,7 +34,7 @@ public:
     ~Osd() override;
 
     void showGenericOsd(const QString &icon, const QString &text);
-    void showOutputIdentifier(const KScreen::OutputPtr &output);
+    void showOutputIdentifier(const KScreen::OutputPtr &output, bool shouldShouldSerialNumber);
     void showActionSelector();
     void hideOsd();
 
@@ -47,12 +47,9 @@ private Q_SLOTS:
 
 private:
     bool initOsd();
-    void showOsd();
-    void updatePosition();
 
     KScreen::OutputPtr m_output;
     QRect m_outputGeometry;
-    KDeclarative::QmlObject *m_osdObject = nullptr;
     KDeclarative::QmlObject *m_osdActionSelector = nullptr;
     QTimer *m_osdTimer = nullptr;
     int m_timeout = 0;
